about summary refs log tree commit diff
path: root/sysdeps/unix/sysv/linux/writev.c
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/unix/sysv/linux/writev.c')
-rw-r--r--sysdeps/unix/sysv/linux/writev.c15
1 files changed, 6 insertions, 9 deletions
diff --git a/sysdeps/unix/sysv/linux/writev.c b/sysdeps/unix/sysv/linux/writev.c
index 11afd81d2e..d147186b51 100644
--- a/sysdeps/unix/sysv/linux/writev.c
+++ b/sysdeps/unix/sysv/linux/writev.c
@@ -25,15 +25,12 @@
 extern ssize_t __syscall_writev __P ((int, const struct iovec *, int));
 
 /* Not all versions of the kernel support the large number of records.  */
-#undef MAX_IOVEC
-#ifdef UIO_FASTIOV
-# define MAX_IOVEC	UIO_FASTIOV
-#else
-# define MAX_IOVEC	8	/* 8 is a safe number. */
+#ifndef UIO_FASTIOV
+# define UIO_FASTIOV	8	/* 8 is a safe number.  */
 #endif
 
 
 /* We should deal with kernel which have a smaller UIO_MAXIOV as well
    as a very big count.  */
 ssize_t
 writev (fd, vector, count)
@@ -46,7 +43,7 @@ writev (fd, vector, count)
 
   bytes_written = __syscall_writev (fd, vector, count);
 
-  if (bytes_written < 0 && errno == EINVAL && count > MAX_IOVEC)
+  if (bytes_written < 0 && errno == EINVAL && count > UIO_FASTIOV)
     {
       int i;
 
@@ -54,10 +51,10 @@ writev (fd, vector, count)
       __set_errno (errno_saved);
 
       bytes_written = 0;
-      for (i = 0; i < count; i += MAX_IOVEC)
+      for (i = 0; i < count; i += UIO_FASTIOV)
 	{
 	  ssize_t bytes = __syscall_writev (fd, vector + i,
-					    MIN (count - i, MAX_IOVEC));
+					    MIN (count - i, UIO_FASTIOV));
 
 	  if (bytes < 0)
 	    return bytes_written > 0 ? bytes_written : bytes;
@@ -25,15 +25,12 @@
 
 
-/* We should deal with kernel which have a smaller UIO_MAXIOV as well
+/* We should deal with kernel which have a smaller UIO_FASTIOV as well
    as a very big count.  */
 ssize_t